@@ -6,13 +6,14 @@ from unit.models.applicationForm import ApplicationFormDTO
 from unit.models.application import IndividualApplicationDTO, BusinessApplicationDTO, ApplicationDocumentDTO
 from unit.models.account import DepositAccountDTO, AccountLimitsDTO
 from unit.models.customer import IndividualCustomerDTO, BusinessCustomerDTO
-from unit.models.card import IndividualDebitCardDTO, BusinessDebitCardDTO, IndividualVirtualDebitCardDTO, BusinessVirtualDebitCardDTO
+from unit.models.card import IndividualDebitCardDTO, BusinessDebitCardDTO, IndividualVirtualDebitCardDTO,\
+    BusinessVirtualDebitCardDTO, PinStatusDTO, CardLimitsDTO
 from unit.models.transaction import *
 from unit.models.payment import AchPaymentDTO, BookPaymentDTO, WirePaymentDTO
 from unit.models.customerToken import CustomerTokenDTO, CustomerVerificationTokenDTO
 from unit.models.fee import FeeDTO
 from unit.models.event import *
-from unit.models.counterparty import CounterpartyDTO
+from unit.models.counterparty import CounterpartyDTO, CounterpartyBalanceDTO
 from unit.models.webhook import WebhookDTO
 from unit.models.institution import InstitutionDTO
 from unit.models.statement import StatementDTO
@@ -207,6 +208,9 @@ mappings = {
         "customer.created": lambda _id, _type, attributes, relationships:
         CustomerCreatedEvent.from_json_api(_id, _type, attributes, relationships),
 
+        "account.reopened": lambda _id, _type, attributes, relationships:
+        AccountReopenedEvent.from_json_api(_id, _type, attributes, relationships),
+
         "webhook": lambda _id, _type, attributes, relationships:
         WebhookDTO.from_json_api(_id, _type, attributes, relationships),
 
@@ -231,6 +235,15 @@ mappings = {
         "accountEndOfDay": lambda _id, _type, attributes, relationships:
         AccountEndOfDayDTO.from_json_api(_id, _type, attributes, relationships),
 
+        "counterpartyBalance": lambda _id, _type, attributes, relationships:
+        CounterpartyBalanceDTO.from_json_api(_id, _type, attributes, relationships),
+
+        "pinStatus": lambda _id, _type, attributes, relationships:
+        PinStatusDTO.from_json_api(attributes),
+
+        "limits": lambda _id, _type, attributes, relationships:
+        CardLimitsDTO.from_json_api(_id, _type, attributes, relationships)
+
     }
 
 
@@ -332,8 +345,8 @@ class UnitEncoder(json.JSONEncoder):
         if isinstance(obj, Relationship):
             return {"data": obj.to_dict()}
         if isinstance(obj, Counterparty):
-            return {"routingNumber": obj.routingNumber, "accountNumber": obj.accountNumber,
-                    "accountType": obj.accountType, "name": obj.name}
+            return {"routingNumber": obj.routing_number, "accountNumber": obj.account_number,
+                    "accountType": obj.account_type, "name": obj.name}
         if isinstance(obj, Coordinates):
             return {"longitude": obj.longitude, "latitude": obj.latitude}
         return json.JSONEncoder.default(self, obj)
