@@ -109,3 +109,15 @@ class PatchCounterpartyRequest(object):
     def __repr__(self):
         json.dumps(self.to_json_api())
 
+
+class CounterpartyBalanceDTO(object):
+    def __init__(self, id: str, balance: int, available: int, relationships: [Dict[str, Relationship]]):
+        self.id = id
+        self.type = "counterpartyBalance"
+        self.attributes = {"balance": balance, "available": available}
+        self.relationships = relationships
+
+    @staticmethod
+    def from_json_api(_id, _type, attributes, relationships):
+        return CounterpartyBalanceDTO(_id, attributes["balance"], attributes["available"], relationships)
+
